@@ -48,3 +48,20 @@ bread.hurdle <- function(x, ...) {
 bread.zeroinfl <- function(x, ...) {
   x$vcov * x$n
 }
+
+bread.mlogit <- function(x, ...)
+{
+  vcov(x) * length(residuals(x))
+}
+
+bread.rlm <- function(x, ...) {
+  xmat <- model.matrix(x)
+  xmat <- naresid(x$na.action, xmat)
+  wts <- weights(x)
+  if(is.null(wts)) wts <- 1
+  res <- residuals(x)
+  psi_deriv <- function(z) x$psi(z, deriv = 1)
+  rval <- sqrt(abs(as.vector(psi_deriv(res/x$s)/x$s))) * wts * xmat    
+  rval <- chol2inv(qr.R(qr(rval))) * nrow(xmat)
+  return(rval)
+}
